plan_face

Function plan_face 

fn plan_face(
    face: Base14Font,
    chars: &BTreeSet<char>,
    diagnostics: &mut Vec<Diagnostic>,
) -> DocEncoding
Computes the encoding plan for a single face given the set of chars the document needs from it.