fn plan_face(
face: Base14Font,
chars: &BTreeSet<char>,
diagnostics: &mut Vec<Diagnostic>,
) -> DocEncodingExpand description
Computes the encoding plan for a single face given the set of chars the document needs from it.
fn plan_face(
face: Base14Font,
chars: &BTreeSet<char>,
diagnostics: &mut Vec<Diagnostic>,
) -> DocEncodingComputes the encoding plan for a single face given the set of chars the document needs from it.